@@ -52,7 +52,7 @@ static JSBool byte_array_set_prop      (JSContext    *context,
 static JSBool byte_array_new_resolve   (JSContext    *context,
                                         JSObject     *obj,
                                         jsid          id,
-                                        uintN         flags,
+                                        unsigned      flags,
                                         JSObject    **objp);
 GJS_NATIVE_CONSTRUCTOR_DECLARE(byte_array);
 static void   byte_array_finalize      (JSContext    *context,
@@ -62,8 +62,7 @@ static void   byte_array_finalize      (JSContext    *context,
 static struct JSClass gjs_byte_array_class = {
     "ByteArray",
     JSCLASS_HAS_PRIVATE |
-    JSCLASS_NEW_RESOLVE |
-    JSCLASS_NEW_RESOLVE_GETS_START,
+    JSCLASS_NEW_RESOLVE,
     JS_PropertyStub,
     JS_PropertyStub,
     byte_array_get_prop,
@@ -216,8 +215,6 @@ byte_array_get_prop(JSContext *context,
     priv = priv_from_js(context, obj);
 
     if (priv == NULL)
-        return JS_FALSE; /* wrong class passed in */
-    if (priv->array == NULL && priv->bytes == NULL)
         return JS_TRUE; /* prototype, not an instance. */
 
     if (!JS_IdToValue(context, id, &id_value))
@@ -245,13 +242,11 @@ byte_array_length_getter(JSContext *context,
                          jsval     *value_p)
 {
     ByteArrayInstance *priv;
-    gsize len;
+    gsize len = 0;
 
     priv = priv_from_js(context, obj);
 
     if (priv == NULL)
-        return JS_FALSE; /* wrong class passed in */
-    if (priv->array == NULL && priv->bytes == NULL)
         return JS_TRUE; /* prototype, not an instance. */
 
     if (priv->array != NULL)
@@ -274,9 +269,7 @@ byte_array_length_setter(JSContext *context,
     priv = priv_from_js(context, obj);
 
     if (priv == NULL)
-        return JS_FALSE; /* wrong class passed in */
-    if (priv->array == NULL && priv->bytes == NULL)
-        return JS_TRUE; /* prototype, not an instance. */
+        return JS_TRUE; /* prototype, not instance */
 
     byte_array_ensure_array(priv);
 
@@ -338,8 +331,6 @@ byte_array_set_prop(JSContext *context,
     priv = priv_from_js(context, obj);
 
     if (priv == NULL)
-        return JS_FALSE; /* wrong class passed in */
-    if (priv->array == NULL && priv->bytes == NULL)
         return JS_TRUE; /* prototype, not an instance. */
 
     if (!JS_IdToValue(context, id, &id_value))
@@ -366,37 +357,21 @@ byte_array_set_prop(JSContext *context,
     return JS_TRUE;
 }
 
-/*
- * Like JSResolveOp, but flags provide contextual information as follows:
- *
- *  JSRESOLVE_QUALIFIED   a qualified property id: obj.id or obj[id], not id
- *  JSRESOLVE_ASSIGNING   obj[id] is on the left-hand side of an assignment
- *  JSRESOLVE_DETECTING   'if (o.p)...' or similar detection opcode sequence
- *  JSRESOLVE_DECLARING   var, const, or function prolog declaration opcode
- *  JSRESOLVE_CLASSNAME   class name used when constructing
- *
- * The *objp out parameter, on success, should be null to indicate that id
- * was not resolved; and non-null, referring to obj or one of its prototypes,
- * if id was resolved.
- *
- * *objp will be the original object the property access was on, rather than the
- * prototype that "obj" may be, due to JSCLASS_NEW_RESOLVE_GETS_START
- */
 static JSBool
 byte_array_new_resolve(JSContext *context,
                        JSObject  *obj,
                        jsid       id,
-                       uintN      flags,
+                       unsigned   flags,
                        JSObject **objp)
 {
     ByteArrayInstance *priv;
     jsval id_val;
 
-    priv = priv_from_js(context, *objp);
+    *objp = NULL;
+
+    priv = priv_from_js(context, obj);
 
     if (priv == NULL)
-        return JS_FALSE; /* wrong class passed in */
-    if (priv->array == NULL && priv->bytes == NULL)
         return JS_TRUE; /* prototype, not an instance. */
 
     if (!JS_IdToValue(context, id, &id_val))
@@ -408,12 +383,7 @@ byte_array_new_resolve(JSContext *context,
         gsize idx;
         if (!gjs_value_to_gsize(context, id_val, &idx))
             return JS_FALSE;
-        if (idx >= priv->array->len) {
-            *objp = NULL;
-        } else {
-            /* leave objp set */
-            g_assert(*objp != NULL);
-
+        if (idx < priv->array->len) {
             /* define the property - AAARGH. Best I can tell from
              * reading the source, this is unavoidable...
              * which means using "for each" or "for ... in" on byte
@@ -424,13 +394,15 @@ byte_array_new_resolve(JSContext *context,
              * a property but must define it.
              */
             if (!JS_DefinePropertyById(context,
-                                       *objp,
+                                       obj,
                                        id,
                                        JSVAL_VOID,
                                        byte_array_get_prop,
                                        byte_array_set_prop,
                                        JSPROP_ENUMERATE))
                 return JS_FALSE;
+
+            *objp = obj;
         }
     }
 
@@ -511,7 +483,7 @@ byte_array_finalize(JSContext *context,
 /* implement toString() with an optional encoding arg */
 static JSBool
 to_string_func(JSContext *context,
-               uintN      argc,
+               unsigned   argc,
                jsval     *vp)
 {
     jsval *argv = JS_ARGV(context, vp);
@@ -524,15 +496,13 @@ to_string_func(JSContext *context,
     priv = priv_from_js(context, object);
 
     if (priv == NULL)
-        return JS_FALSE; /* wrong class passed in */
+        return JS_TRUE; /* prototype, not instance */
 
     byte_array_ensure_array(priv);
 
-    encoding_is_utf8 = TRUE;
     if (argc >= 1 &&
         JSVAL_IS_STRING(argv[0])) {
-        encoding = gjs_string_get_ascii(context, argv[0]);
-        if (encoding == NULL)
+        if (!gjs_string_to_utf8(context, argv[0], &encoding))
             return JS_FALSE;
 
         /* maybe we should be smarter about utf8 synonyms here.
@@ -540,13 +510,14 @@ to_string_func(JSContext *context,
          * just an optimization anyway.
          */
         if (strcmp(encoding, "UTF-8") == 0) {
-            g_free(encoding);
             encoding_is_utf8 = TRUE;
+            g_free(encoding);
+            encoding = NULL;
         } else {
             encoding_is_utf8 = FALSE;
         }
     } else {
-        encoding = "UTF-8";
+        encoding_is_utf8 = TRUE;
     }
 
     if (priv->array->len == 0)
@@ -557,7 +528,7 @@ to_string_func(JSContext *context,
 
     if (encoding_is_utf8) {
         /* optimization, avoids iconv overhead and runs
-         * glib's hardwired utf8-to-utf16
+         * libmozjs hardwired utf8-to-utf16
          */
         jsval retval;
         JSBool ok;
@@ -611,7 +582,7 @@ to_string_func(JSContext *context,
 
 static JSBool
 to_gbytes_func(JSContext *context,
-               uintN      argc,
+               unsigned   argc,
                jsval     *vp)
 {
     JSObject *object = JS_THIS_OBJECT(context, vp);
@@ -621,7 +592,7 @@ to_gbytes_func(JSContext *context,
 
     priv = priv_from_js(context, object);
     if (priv == NULL)
-        return JS_FALSE; /* wrong class passed in */
+        return JS_TRUE; /* prototype, not instance */
     
     byte_array_ensure_gbytes(priv);
 
@@ -652,7 +623,7 @@ byte_array_new(JSContext *context)
 /* fromString() function implementation */
 static JSBool
 from_string_func(JSContext *context,
-                 uintN      argc,
+                 unsigned   argc,
                  jsval     *vp)
 {
     jsval *argv = JS_ARGV(context, vp);
@@ -681,11 +652,9 @@ from_string_func(JSContext *context,
         goto out;
     }
 
-    encoding_is_utf8 = TRUE;
     if (argc > 1 &&
         JSVAL_IS_STRING(argv[1])) {
-        encoding = gjs_string_get_ascii(context, argv[1]);
-        if (encoding == NULL)
+        if (!gjs_string_to_utf8(context, argv[1], &encoding))
             goto out;
 
         /* maybe we should be smarter about utf8 synonyms here.
@@ -693,22 +662,19 @@ from_string_func(JSContext *context,
          * just an optimization anyway.
          */
         if (strcmp(encoding, "UTF-8") == 0) {
-            g_free(encoding);
             encoding_is_utf8 = TRUE;
+            g_free(encoding);
+            encoding = NULL;
         } else {
             encoding_is_utf8 = FALSE;
         }
     } else {
-        encoding = "UTF-8";
+        encoding_is_utf8 = TRUE;
     }
 
     if (encoding_is_utf8) {
         /* optimization? avoids iconv overhead and runs
-         * glib's hardwired utf16-to-utf8.
-         * Does a gratuitous copy/strlen, but
-         * the generic path below also has
-         * gratuitous copy. Could be fixed for this path,
-         * if it ever turns out to matter.
+         * libmozjs hardwired utf16-to-utf8.
          */
         char *utf8 = NULL;
         if (!gjs_string_to_utf8(context,
@@ -750,7 +716,7 @@ from_string_func(JSContext *context,
 
         g_free(encoded);
     }
-    
+
     JS_SET_RVAL(context, vp, OBJECT_TO_JSVAL(obj));
 
     retval = JS_TRUE;
@@ -762,13 +728,13 @@ from_string_func(JSContext *context,
 /* fromArray() function implementation */
 static JSBool
 from_array_func(JSContext *context,
-                uintN      argc,
+                unsigned   argc,
                 jsval     *vp)
 {
     jsval *argv = JS_ARGV(context, vp);
     ByteArrayInstance *priv;
-    jsuint len;
-    jsuint i;
+    guint32 len;
+    guint32 i;
     JSObject *obj;
     JSBool ret = JS_FALSE;
 
@@ -829,7 +795,7 @@ from_array_func(JSContext *context,
 
 static JSBool
 from_gbytes_func(JSContext *context,
-                 uintN      argc,
+                 unsigned   argc,
                  jsval     *vp)
 {
     jsval *argv = JS_ARGV(context, vp);
