@@ -75,11 +75,15 @@ typedef struct GjsRootedArray GjsRootedArray;
     {                                                                   \
         return gjs_typecheck_instance(context, object, &class, throw);  \
     }                                                                   \
-    static inline type*                                                 \
+    static inline type *                                                \
     priv_from_js(JSContext *context,                                    \
                  JSObject  *object)                                     \
     {                                                                   \
-        return JS_GetInstancePrivate(context, object, &class, NULL);    \
+        type *priv;                                                     \
+        JS_BeginRequest(context);                                       \
+        priv = JS_GetInstancePrivate(context, object, &class, NULL);    \
+        JS_EndRequest(context);                                         \
+        return priv;                                                    \
     }                                                                   \
     __attribute__((unused)) static JSBool                               \
     priv_from_js_with_typecheck(JSContext *context,                     \
@@ -122,7 +126,7 @@ static void gjs_##cname##_finalize(JSContext *context, JSObject *obj); \
 static JSBool gjs_##cname##_new_resolve(JSContext *context, \
                                         JSObject  *obj, \
                                         jsval      id, \
-                                        uintN      flags, \
+                                        unsigned   flags, \
                                         JSObject **objp) \
 { \
     return JS_TRUE; \
@@ -130,8 +134,7 @@ static JSBool gjs_##cname##_new_resolve(JSContext *context, \
 static struct JSClass gjs_##cname##_class = { \
     type_name, \
     JSCLASS_HAS_PRIVATE | \
-    JSCLASS_NEW_RESOLVE | \
-    JSCLASS_NEW_RESOLVE_GETS_START, \
+    JSCLASS_NEW_RESOLVE, \
     JS_PropertyStub, \
     JS_PropertyStub, \
     JS_PropertyStub, \
@@ -170,23 +173,14 @@ jsval gjs_##cname##_create_proto(JSContext *context, JSObject *module, const cha
         } \
         if (!JS_DefineProperty(context, module, proto_name, \
                                rval, NULL, NULL, GJS_MODULE_PROP_FLAGS)) \
-            return JS_FALSE; \
+            return JSVAL_NULL; \
     } \
     return rval; \
 }
 
 gboolean    gjs_init_context_standard        (JSContext       *context);
 
-void        gjs_runtime_init                 (JSRuntime       *runtime);
-void        gjs_runtime_destroy              (JSRuntime       *runtime);
-
-JSContext*  gjs_runtime_get_current_context  (JSRuntime       *runtime);
-void        gjs_runtime_set_default_context  (JSRuntime       *runtime,
-                                              JSContext       *context);
-JSContext*  gjs_runtime_get_default_context  (JSRuntime       *runtime);
-void        gjs_runtime_push_context         (JSRuntime       *runtime,
-                                              JSContext       *context);
-void        gjs_runtime_pop_context          (JSRuntime       *runtime);
+JSContext*  gjs_runtime_get_context          (JSRuntime       *runtime);
 JSObject*   gjs_get_import_global            (JSContext       *context);
 gboolean    gjs_object_has_property          (JSContext       *context,
                                               JSObject        *obj,
@@ -211,7 +205,7 @@ JSBool      gjs_init_class_dynamic           (JSContext       *context,
                                               const char      *class_name,
                                               JSClass         *clasp,
                                               JSNative         constructor,
-                                              uintN            nargs,
+                                              unsigned         nargs,
                                               JSPropertySpec  *ps,
                                               JSFunctionSpec  *fs,
                                               JSPropertySpec  *static_ps,
@@ -229,14 +223,14 @@ JSBool gjs_typecheck_instance                 (JSContext  *context,
 
 JSObject*   gjs_construct_object_dynamic     (JSContext       *context,
                                               JSObject        *proto,
-                                              uintN            argc,
+                                              unsigned         argc,
                                               jsval           *argv);
 JSObject*   gjs_define_string_array          (JSContext       *context,
                                               JSObject        *obj,
                                               const char      *array_name,
                                               gssize           array_length,
                                               const char     **array_values,
-                                              uintN            attrs);
+                                              unsigned         attrs);
 void        gjs_throw                        (JSContext       *context,
                                               const char      *format,
                                               ...)  G_GNUC_PRINTF (2, 3);
@@ -269,7 +263,7 @@ void        gjs_explain_scope                (JSContext       *context,
 JSBool      gjs_call_function_value          (JSContext       *context,
                                               JSObject        *obj,
                                               jsval            fval,
-                                              uintN            argc,
+                                              unsigned         argc,
                                               jsval           *argv,
                                               jsval           *rval);
 void        gjs_error_reporter               (JSContext       *context,
@@ -306,16 +300,6 @@ JSBool      gjs_string_from_filename         (JSContext       *context,
                                               const char      *filename_string,
                                               gssize           n_bytes,
                                               jsval           *value_p);
-char*       gjs_string_get_ascii             (JSContext       *context,
-                                              jsval            value);
-JSBool      gjs_string_get_binary_data       (JSContext       *context,
-                                              jsval            value,
-                                              char           **data_p,
-                                              gsize           *len_p);
-JSBool      gjs_string_from_binary_data      (JSContext       *context,
-                                              const char      *data,
-                                              gsize            len,
-                                              jsval           *value_p);
 JSBool      gjs_string_get_uint16_data       (JSContext       *context,
                                               jsval            value,
                                               guint16        **data_p,
@@ -340,7 +324,7 @@ jsval       gjs_date_from_time_t             (JSContext *context, time_t time);
 JSBool      gjs_parse_args                   (JSContext  *context,
                                               const char *function_name,
                                               const char *format,
-                                              uintN      argc,
+                                              unsigned   argc,
                                               jsval     *argv,
                                               ...);
 
@@ -371,16 +355,6 @@ void              gjs_unroot_value_locations  (JSContext        *context,
 
 /* Functions intended for more "internal" use */
 
-gboolean gjs_try_string_to_filename           (JSContext    *context,
-                                               const jsval   filename_val,
-                                               char        **filename_string_p,
-                                               GError      **error);
-
-gboolean    gjs_try_string_to_utf8            (JSContext       *context,
-                                               const            jsval string_val,
-                                               char           **utf8_string_p,
-                                               GError         **error);
-
 void gjs_maybe_gc (JSContext *context);
 
 G_END_DECLS
