@@ -184,7 +184,6 @@ gjs_debug(GjsDebugTopic topic,
         return;
 
     error = FALSE;
-    prefix = "???";
     switch (topic) {
     case GJS_DEBUG_STRACE_TIMESTAMP:
         /* return early if strace timestamps are disabled, avoiding
@@ -220,12 +219,6 @@ gjs_debug(GjsDebugTopic topic,
     case GJS_DEBUG_NATIVE:
         prefix = "JS NATIVE";
         break;
-    case GJS_DEBUG_DBUS:
-        prefix = "JS DBUS";
-        break;
-    case GJS_DEBUG_DBUS_MARSHAL:
-        prefix = "JS DBUS MARSHAL";
-        break;
     case GJS_DEBUG_KEEP_ALIVE:
         prefix = "JS KP ALV";
         break;
@@ -280,6 +273,9 @@ gjs_debug(GjsDebugTopic topic,
     case GJS_DEBUG_GERROR:
         prefix = "JS G ERR";
         break;
+    default:
+        prefix = "???";
+        break;
     }
 
     if (!is_allowed_prefix(prefix))
